==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/HorizontalStackedSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedSeriesBaseDescriptionMetadata } from "./StackedSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
export let HorizontalStackedSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class HorizontalStackedSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (HorizontalStackedSeriesBaseDescriptionMetadata.a == null) {
                HorizontalStackedSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HorizontalStackedSeriesBaseDescriptionMetadata.c(HorizontalStackedSeriesBaseDescriptionMetadata.a);
            }
            if (a.j(HorizontalStackedSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.y(HorizontalStackedSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            StackedSeriesBaseDescriptionMetadata.c(a);
            a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
            a.item("XAxisRef@nameBinding", "true");
            a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
            a.item("YAxisRef@nameBinding", "true");
        }
        static d(a) {
            HorizontalStackedSeriesBaseDescriptionMetadata.b(a);
            a.z("HorizontalStackedSeriesBase", HorizontalStackedSeriesBaseDescriptionMetadata.a);
        }
    }
    HorizontalStackedSeriesBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(HorizontalStackedSeriesBaseDescriptionMetadata, 'HorizontalStackedSeriesBaseDescriptionMetadata');
    HorizontalStackedSeriesBaseDescriptionMetadata.a = null;
    return HorizontalStackedSeriesBaseDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/HorizontalStackedSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedSeriesBaseDescriptionMetadata } from "./StackedSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
export let HorizontalStackedSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class HorizontalStackedSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (HorizontalStackedSeriesBaseDescriptionMetadata.a == null) {
                HorizontalStackedSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HorizontalStackedSeriesBaseDescriptionMetadata.c(HorizontalStackedSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(HorizontalStackedSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.aa(HorizontalStackedSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            StackedSeriesBaseDescriptionMetadata.c(a);
            a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
            a.item("XAxisRef@nameBinding", "true");
            a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
            a.item("YAxisRef@nameBinding", "true");
        }
        static d(a) {
            HorizontalStackedSeriesBaseDescriptionMetadata.b(a);
            a.ab("HorizontalStackedSeriesBase", HorizontalStackedSeriesBaseDescriptionMetadata.a);
        }
    }
    HorizontalStackedSeriesBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(HorizontalStackedSeriesBaseDescriptionMetadata, 'HorizontalStackedSeriesBaseDescriptionMetadata');
    HorizontalStackedSeriesBaseDescriptionMetadata.a = null;
    return HorizontalStackedSeriesBaseDescriptionMetadata;
})();
